@@ -6,7 +6,7 @@ import uuid
 from typing import List, Tuple, Dict, Type
 
 from graphql.language import ast
-from requests.exceptions import ConnectionError
+from requests.exceptions import RequestException
 
 from graphql import (
     GraphQLInputObjectType,
@@ -159,7 +159,7 @@ class GraphQLRemoteExecutor(GraphQLBaseExecutor, GraphQLObjectType):
                 http_timeout=self.http_timeout,
                 verify=self.verify
             )
-        except ConnectionError as e:
+        except RequestException as e:
             import sys
             err_msg = f"{e}, remote service '{self.name}' is unavailable."
             raise type(e)(err_msg).with_traceback(sys.exc_info()[2])
